@@ -34,6 +34,11 @@ class CommandLine(object):
 
 @dataclass
 class Choice:
+    """name: metavar or option name
+    is_position: Argument is positional if True, -- style option if not
+    default: Default value for choice, if any
+    help: Header for help. Choice values are added automatically
+    """
     name: str
     is_position: bool
     default: object = None
